# synteny_2d_plot.R
# make dot plot of synteny between two genomes, based on unidirectional blast hits (i.e. not reciprocal)
# created by WRF 2019-04-01
# last modified 2020-01-31


# make PDF
outputfile = "~/genomes/ephydatia_muelleri/synteny/ephydatia_combined_synteny_dot_plots.pdf"
pdf(file=outputfile, width=8, height=6)
par( mar=c(3.5,3.5,1,0.5) )
par( mfrow=c(2,3) )

# dotcolor = "#18935188" # green
# dotcolor = "#c51b8a88" # pink
# dotcolor = "#1c909988" # teal
# dotcolor = "#2071d388" # blue

###
### DRAW TRICHOPLAX
###

all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Triad1_scaffold2D.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
longestscaf1 = max(scafdata1[,6])
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.01)
longscafs1 = c(0, scafdata1[,6][is_longscafs1] )
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
longestscaf2 = max(scafdata2[,6])
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.0009)
longscafs2 = c(0, scafdata2[,6][is_longscafs2] )
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
longscafpoints = pointsdata[,6] < 270000000
genome_x = pointsdata[,7][longscafpoints]
genome_y = pointsdata[,6][longscafpoints]
xmax = tail( pretty(longscafs2), n=1)
ymax = tail( pretty(longscafs1), n=1)
longscafs_x = longscafs2
longscafs_y = longscafs1
nscafs_x = length(longscafs2)
nscafs_y = length(longscafs1)
xmax_mb = round(xmax / 1000000)
ymax_mb = round(ymax / 1000000)
pointsize = log10(as.numeric(pointsdata[,8])) / 6
plot(genome_x, genome_y, pch=16, ylim=c(0,270000000), col="#18935188", cex=pointsize, main="Trichoplax adhaerens", font.main=3, xlab="", ylab="", axes=FALSE, cex.lab=1.4)
tickpoints = pretty(c(0,100))
axis(1, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_x = rep(c( ymax*-0.01, ymax*-0.02),round(nscafs_x)/2)
segments( longscafs_x[1:(nscafs_x-1)], barpos_x[1:(nscafs_x-1)], longscafs_x[2:nscafs_x], barpos_x[0:(nscafs_x-1)], lwd=2)
segments(longscafs_x, 0, longscafs_x, longscafs_y[nscafs_y], lwd=0.1, col="#777777")
tickpoints = pretty(c(0,250))
axis(2, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_y = rep(c( xmax*-0.01, xmax*-0.02),round(nscafs_y)/2)
segments( barpos_y[1:(nscafs_y-1)], longscafs_y[1:(nscafs_y-1)], barpos_y[0:(nscafs_y-1)], longscafs_y[2:nscafs_y], lwd=2)
segments( 0, longscafs_y, longscafs_x[nscafs_x], longscafs_y, lwd=0.1, col="#777777")
textpos_y = rep(c( xmax*-0.02, xmax*-0.01 ),round(24)/2)
textmidbar = as.numeric(scafdata1[1:24,6]) - as.numeric(scafdata1[1:24,4])/2
text(textpos_y, textmidbar, 1:24, cex=0.2)

###
### DRAW NEMATOSTELLA
###

par( mar=c(3.5,4.5,1,0.5) )


all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Nve2_scaffold2D.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
longestscaf1 = max(scafdata1[,6])
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.01)
longscafs1 = c(0, scafdata1[,6][is_longscafs1] )
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
longestscaf2 = max(scafdata2[,6])
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.0009)
longscafs2 = c(0, scafdata2[,6][is_longscafs2] )
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
longscafpoints = pointsdata[,6] < 270000000
genome_x = pointsdata[,7][longscafpoints]
genome_y = pointsdata[,6][longscafpoints]
xmax = tail( pretty(longscafs2), n=1)
ymax = tail( pretty(longscafs1), n=1)
longscafs_x = longscafs2
longscafs_y = longscafs1
nscafs_x = length(longscafs2)
nscafs_y = length(longscafs1)
xmax_mb = round(xmax / 1000000)
ymax_mb = round(ymax / 1000000)
pointsize = log10(as.numeric(pointsdata[,8])) / 6
plot(genome_x, genome_y, pch=16, xlim=c(0,101000000), ylim=c(0,270000000), col="#18935188", cex=pointsize, main="Nematostella vectensis", font.main=3, xlab="", ylab="Total size (Mb)", axes=FALSE, cex.lab=1.4)
tickpoints = pretty(c(0,100))
axis(1, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_x = rep(c( ymax*-0.01, ymax*-0.02),round(nscafs_x)/2)
segments( longscafs_x[1:(nscafs_x-1)], barpos_x[1:(nscafs_x-1)], longscafs_x[2:nscafs_x], barpos_x[0:(nscafs_x-1)], lwd=2)
segments( longscafs_x, 0, longscafs_x, longscafs_y[nscafs_y], lwd=0.1, col="#777777")
tickpoints = pretty(c(0,250))
axis(2, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_y = rep(c( xmax*-0.006, xmax*-0.012),round(nscafs_y)/2)
segments( barpos_y[1:(nscafs_y-1)], longscafs_y[1:(nscafs_y-1)], barpos_y[0:(nscafs_y-1)], longscafs_y[2:nscafs_y], lwd=2)
segments( 0, longscafs_y, longscafs_x[nscafs_x], longscafs_y, lwd=0.1, col="#777777")
textpos_y = rep(c( xmax*-0.02, xmax*-0.01 ),round(24)/2)
textmidbar = as.numeric(scafdata1[1:24,6]) - as.numeric(scafdata1[1:24,4])/2
text(textpos_y, textmidbar, 1:24, cex=0.2)

###
### DRAW BRANCHIOSTOMA
###

all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Brafl2-AUG_scaffold2D.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
longestscaf1 = max(scafdata1[,6])
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.01)
longscafs1 = c(0, scafdata1[,6][is_longscafs1] )
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
longestscaf2 = max(scafdata2[,6])
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.0009)
longscafs2 = c(0, scafdata2[,6][is_longscafs2] )
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
longscafpoints = pointsdata[,6] < 270000000
genome_x = pointsdata[,7][longscafpoints]
genome_y = pointsdata[,6][longscafpoints]
xmax = tail( pretty(longscafs2), n=1)
ymax = tail( pretty(longscafs1), n=1)
longscafs_x = longscafs2
longscafs_y = longscafs1
nscafs_x = length(longscafs2)
nscafs_y = length(longscafs1)
xmax_mb = round(xmax / 1000000)
ymax_mb = round(ymax / 1000000)
pointsize = log10(as.numeric(pointsdata[,8])) / 6
plot(genome_x, genome_y, pch=16, xlim=c(0,200000000), ylim=c(0,270000000), col="#18935188", cex=pointsize, main="Branchiostoma floridae", font.main=3, xlab="", ylab="Total size (Mb)", axes=FALSE, cex.lab=1.4)
tickpoints = pretty(c(0,200))
axis(1, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_x = rep(c( ymax*-0.01, ymax*-0.02),round(nscafs_x)/2)
segments( longscafs_x[1:(nscafs_x-1)], barpos_x[1:(nscafs_x-1)], longscafs_x[2:nscafs_x], barpos_x[0:(nscafs_x-1)], lwd=2)
segments(longscafs_x, 0, longscafs_x, longscafs_y[nscafs_y], lwd=0.1, col="#777777")
tickpoints = pretty(c(0,250))
axis(2, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_y = rep(c( xmax*-0.01, xmax*-0.02),round(nscafs_y)/2)
segments( barpos_y[1:(nscafs_y-1)], longscafs_y[1:(nscafs_y-1)], barpos_y[0:(nscafs_y-1)], longscafs_y[2:nscafs_y], lwd=2)
segments( 0, longscafs_y, longscafs_x[nscafs_x], longscafs_y, lwd=0.1, col="#777777")
textpos_y = rep(c( xmax*-0.02, xmax*-0.01 ),round(24)/2)
textmidbar = as.numeric(scafdata1[1:24,6]) - as.numeric(scafdata1[1:24,4])/2
text(textpos_y, textmidbar, 1:24, cex=0.2)

###
### DRAW MONOSIGA
###

par( mar=c(4.5,3.5,1,0.5) )


all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Monosiga_scaffold2D.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
longestscaf1 = max(scafdata1[,6])
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.01)
longscafs1 = c(0, scafdata1[,6][is_longscafs1] )
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
longestscaf2 = max(scafdata2[,6])
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.0009)
longscafs2 = c(0, scafdata2[,6][is_longscafs2] )
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
longscafpoints = pointsdata[,6] < 270000000
genome_x = pointsdata[,7][longscafpoints]
genome_y = pointsdata[,6][longscafpoints]
xmax = tail( pretty(longscafs2), n=1)
ymax = tail( pretty(longscafs1), n=1)
longscafs_x = longscafs2
longscafs_y = longscafs1
nscafs_x = length(longscafs2)
nscafs_y = length(longscafs1)
xmax_mb = round(xmax / 1000000)
ymax_mb = round(ymax / 1000000)
pointsize = log10(as.numeric(pointsdata[,8])) / 6
plot(genome_x, genome_y, pch=16, xlim=c(0,40000000), ylim=c(0,270000000), col="#1c909988", cex=pointsize, main="Monosiga brevicollis", font.main=3, xlab="Total size (Mb)", ylab="", axes=FALSE, cex.lab=1.4)
tickpoints = pretty(c(0,40))
axis(1, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_x = rep(c( ymax*-0.01, ymax*-0.02),round(nscafs_x)/2)
segments( longscafs_x[1:(nscafs_x-1)], barpos_x[1:(nscafs_x-1)], longscafs_x[2:nscafs_x], barpos_x[0:(nscafs_x-1)], lwd=2)
segments(longscafs_x, 0, longscafs_x, longscafs_y[nscafs_y], lwd=0.1, col="#777777")
tickpoints = pretty(c(0,250))
axis(2, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_y = rep(c( xmax*-0.01, xmax*-0.02),round(nscafs_y)/2)
segments( barpos_y[1:(nscafs_y-1)], longscafs_y[1:(nscafs_y-1)], barpos_y[0:(nscafs_y-1)], longscafs_y[2:nscafs_y], lwd=2)
segments( 0, longscafs_y, longscafs_x[nscafs_x], longscafs_y, lwd=0.1, col="#777777")
textpos_y = rep(c( xmax*-0.02, xmax*-0.01 ),round(24)/2)
textmidbar = as.numeric(scafdata1[1:24,6]) - as.numeric(scafdata1[1:24,4])/2
text(textpos_y, textmidbar, 1:24, cex=0.2)

###
### DRAW SALPINGOECA
###

par( mar=c(4.5,4.5,1,0.5) )


all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Srosetta_scaffold2D.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
longestscaf1 = max(scafdata1[,6])
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.01)
longscafs1 = c(0, scafdata1[,6][is_longscafs1] )
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
longestscaf2 = max(scafdata2[,6])
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.0009)
longscafs2 = c(0, scafdata2[,6][is_longscafs2] )
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
longscafpoints = pointsdata[,6] < 270000000
genome_x = pointsdata[,7][longscafpoints]
genome_y = pointsdata[,6][longscafpoints]
xmax = tail( pretty(longscafs2), n=1)
ymax = tail( pretty(longscafs1), n=1)
longscafs_x = longscafs2
longscafs_y = longscafs1
nscafs_x = length(longscafs2)
nscafs_y = length(longscafs1)
xmax_mb = round(xmax / 1000000)
ymax_mb = round(ymax / 1000000)
pointsize = log10(as.numeric(pointsdata[,8])) / 6
plot(genome_x, genome_y, pch=16, xlim=c(0,50000000), ylim=c(0,270000000), col="#1c909988", cex=pointsize, main="Salpingoeca rosetta", font.main=3, xlab="Total size (Mb)", ylab="Total size (Mb)", axes=FALSE, cex.lab=1.4)
tickpoints = pretty(c(0,50))
axis(1, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_x = rep(c( ymax*-0.01, ymax*-0.02),round(nscafs_x)/2)
segments( longscafs_x[1:(nscafs_x-1)], barpos_x[1:(nscafs_x-1)], longscafs_x[2:nscafs_x], barpos_x[0:(nscafs_x-1)], lwd=2)
segments(longscafs_x, 0, longscafs_x, longscafs_y[nscafs_y], lwd=0.1, col="#777777")
tickpoints = pretty(c(0,250))
axis(2, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_y = rep(c( xmax*-0.01, xmax*-0.02),round(nscafs_y)/2)
segments( barpos_y[1:(nscafs_y-1)], longscafs_y[1:(nscafs_y-1)], barpos_y[0:(nscafs_y-1)], longscafs_y[2:nscafs_y], lwd=2)
segments( 0, longscafs_y, longscafs_x[nscafs_x], longscafs_y, lwd=0.1, col="#777777")
textpos_y = rep(c( xmax*-0.02, xmax*-0.01 ),round(24)/2)
textmidbar = as.numeric(scafdata1[1:24,6]) - as.numeric(scafdata1[1:24,4])/2
text(textpos_y, textmidbar, 1:24, cex=0.2)

###
### DRAW MONOSIGA AGAINST SALPINGOECA
###

all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/choanoflagellates/monbr1_vs_srosetta_scaffold2d_points.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
longestscaf1 = max(scafdata1[,6])
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.0009)
longscafs1 = c(0, scafdata1[,6][is_longscafs1] )
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
longestscaf2 = max(scafdata2[,6])
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.0009)
longscafs2 = c(0, scafdata2[,6][is_longscafs2] )
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
genome_x = pointsdata[,6]
genome_y = pointsdata[,7]
xmax = tail( pretty(longscafs1), n=1)
ymax = tail( pretty(longscafs2), n=1)
longscafs_x = longscafs1
longscafs_y = longscafs2
nscafs_x = length(longscafs1)
nscafs_y = length(longscafs2)
xmax_mb = round(xmax / 1000000)
ymax_mb = round(ymax / 1000000)
pointsize = log10(as.numeric(pointsdata[,8])) / 6
plot(genome_x, genome_y, pch=16, xlim=c(0,40000000), ylim=c(0,50000000), col="#c51b8a88", cex=pointsize, main="M. brevicollis vs S. rosetta", font.main=3, xlab="Total size (Mb)", ylab="Total size (Mb)", axes=FALSE, cex.lab=1.4)
tickpoints = pretty(c(0,40))
axis(1, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_x = rep(c( ymax*-0.01, ymax*-0.02),round(nscafs_x)/2)
segments( longscafs_x[1:(nscafs_x-1)], barpos_x[1:(nscafs_x-1)], longscafs_x[2:nscafs_x], barpos_x[0:(nscafs_x-1)], lwd=2)
segments(longscafs_x, 0, longscafs_x, longscafs_y[nscafs_y], lwd=0.1, col="#777777")
tickpoints = pretty(c(0,50))
axis(2, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_y = rep(c( xmax*-0.01, xmax*-0.02),round(nscafs_y)/2)
segments( barpos_y[1:(nscafs_y-1)], longscafs_y[1:(nscafs_y-1)], barpos_y[0:(nscafs_y-1)], longscafs_y[2:nscafs_y], lwd=2)
segments( 0, longscafs_y, longscafs_x[nscafs_x], longscafs_y, lwd=0.1, col="#777777")

dev.off()


##
##
##

outputfile = "~/genomes/ephydatia_muelleri/synteny/ephydatia_Ta_Bf_synteny_dot_plots.pdf"
pdf(file=outputfile, width=8, height=5)
par( mar=c(3.5,3.5,1,0.5) )
par( mfrow=c(1,2) )
all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Triad1_scaffold2D.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
longestscaf1 = max(scafdata1[,6])
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.01)
longscafs1 = c(0, scafdata1[,6][is_longscafs1] )
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
longestscaf2 = max(scafdata2[,6])
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.0009)
longscafs2 = c(0, scafdata2[,6][is_longscafs2] )
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
longscafpoints = pointsdata[,6] < 270000000
genome_x = pointsdata[,7][longscafpoints]
genome_y = pointsdata[,6][longscafpoints]
xmax = tail( pretty(longscafs2), n=1)
ymax = tail( pretty(longscafs1), n=1)
longscafs_x = longscafs2
longscafs_y = longscafs1
nscafs_x = length(longscafs2)
nscafs_y = length(longscafs1)
xmax_mb = round(xmax / 1000000)
ymax_mb = round(ymax / 1000000)
pointsize = log10(as.numeric(pointsdata[,8])) / 6
plot(genome_x, genome_y, pch=16, ylim=c(0,270000000), col="#18935188", cex=pointsize, main="Trichoplax adhaerens", font.main=3, xlab="", ylab="", axes=FALSE, cex.lab=1.4)
tickpoints = pretty(c(0,100))
axis(1, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_x = rep(c( ymax*-0.01, ymax*-0.02),round(nscafs_x)/2)
segments( longscafs_x[1:(nscafs_x-1)], barpos_x[1:(nscafs_x-1)], longscafs_x[2:nscafs_x], barpos_x[0:(nscafs_x-1)], lwd=2)
segments(longscafs_x, 0, longscafs_x, longscafs_y[nscafs_y], lwd=0.1, col="#777777")
tickpoints = pretty(c(0,250))
axis(2, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_y = rep(c( xmax*-0.01, xmax*-0.02),round(nscafs_y)/2)
segments( barpos_y[1:(nscafs_y-1)], longscafs_y[1:(nscafs_y-1)], barpos_y[0:(nscafs_y-1)], longscafs_y[2:nscafs_y], lwd=2)
segments( 0, longscafs_y, longscafs_x[nscafs_x], longscafs_y, lwd=0.1, col="#777777")
textpos_y = rep(c( xmax*-0.02, xmax*-0.01 ),round(24)/2)
textmidbar = as.numeric(scafdata1[1:24,6]) - as.numeric(scafdata1[1:24,4])/2
text(textpos_y, textmidbar, 1:24, cex=0.2)
rect(longscafs2[4],longscafs1[22],longscafs2[5],longscafs1[23], border="#ff221166", lwd=3)
par( mar=c(3.5,4.5,1,0.5) )
all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Brafl2-AUG_scaffold2D.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
longestscaf1 = max(scafdata1[,6])
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.01)
longscafs1 = c(0, scafdata1[,6][is_longscafs1] )
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
longestscaf2 = max(scafdata2[,6])
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.0009)
longscafs2 = c(0, scafdata2[,6][is_longscafs2] )
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
longscafpoints = pointsdata[,6] < 270000000
genome_x = pointsdata[,7][longscafpoints]
genome_y = pointsdata[,6][longscafpoints]
xmax = tail( pretty(longscafs2), n=1)
ymax = tail( pretty(longscafs1), n=1)
longscafs_x = longscafs2
longscafs_y = longscafs1
nscafs_x = length(longscafs2)
nscafs_y = length(longscafs1)
xmax_mb = round(xmax / 1000000)
ymax_mb = round(ymax / 1000000)
pointsize = log10(as.numeric(pointsdata[,8])) / 6
plot(genome_x, genome_y, pch=16, xlim=c(0,200000000), ylim=c(0,270000000), col="#18935188", cex=pointsize, main="Branchiostoma floridae", font.main=3, xlab="", ylab="Total size (Mb)", axes=FALSE, cex.lab=1.4)
tickpoints = pretty(c(0,200))
axis(1, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_x = rep(c( ymax*-0.01, ymax*-0.02),round(nscafs_x)/2)
segments( longscafs_x[1:(nscafs_x-1)], barpos_x[1:(nscafs_x-1)], longscafs_x[2:nscafs_x], barpos_x[0:(nscafs_x-1)], lwd=2)
segments(longscafs_x, 0, longscafs_x, longscafs_y[nscafs_y], lwd=0.1, col="#777777")
tickpoints = pretty(c(0,250))
axis(2, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_y = rep(c( xmax*-0.01, xmax*-0.02),round(nscafs_y)/2)
segments( barpos_y[1:(nscafs_y-1)], longscafs_y[1:(nscafs_y-1)], barpos_y[0:(nscafs_y-1)], longscafs_y[2:nscafs_y], lwd=2)
segments( 0, longscafs_y, longscafs_x[nscafs_x], longscafs_y, lwd=0.1, col="#777777")
textpos_y = rep(c( xmax*-0.02, xmax*-0.01 ),round(24)/2)
textmidbar = as.numeric(scafdata1[1:24,6]) - as.numeric(scafdata1[1:24,4])/2
text(textpos_y, textmidbar, 1:24, cex=0.2)
rect(longscafs2[2],longscafs1[22],longscafs2[3],longscafs1[23], border="#ff221166", lwd=3)
rect(longscafs2[17],longscafs1[22],longscafs2[18],longscafs1[23], border="#ff221166", lwd=3)

dev.off()


##############################








outputfile = "~/genomes/ephydatia_muelleri/synteny/ephydatia_Ta_synteny_dot_plots_w_chr22.pdf"
pdf(file=outputfile, width=8, height=5)
par( mar=c(3.5,4.5,1,0.5) )
par( mfrow=c(1,2) )
all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Triad1_scaffold2D.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
longestscaf1 = max(scafdata1[,6])
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.01)
longscafs1 = c(0, scafdata1[,6][is_longscafs1] )
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
longestscaf2 = max(scafdata2[,6])
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.0009)
longscafs2 = c(0, scafdata2[,6][is_longscafs2] )
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
longscafpoints = pointsdata[,6] < 270000000
genome_x = pointsdata[,7][longscafpoints]
genome_y = pointsdata[,6][longscafpoints]
xmax = tail( pretty(longscafs2), n=1)
ymax = tail( pretty(longscafs1), n=1)
longscafs_x = longscafs2
longscafs_y = longscafs1
nscafs_x = length(longscafs2)
nscafs_y = length(longscafs1)
xmax_mb = round(xmax / 1000000)
ymax_mb = round(ymax / 1000000)
pointsize = log10(as.numeric(pointsdata[,8])) / 6
plot(genome_x, genome_y, pch=16, ylim=c(0,270000000), col="#18935188", cex=pointsize, main="Trichoplax adhaerens", font.main=3, xlab="", ylab="", axes=FALSE, cex.lab=1.4)
tickpoints = pretty(c(0,100))
axis(1, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
mtext("Ephydatia muelleri", side=2, font=3, cex=1.4, line=3)
barpos_x = rep(c( ymax*-0.01, ymax*-0.02),round(nscafs_x)/2)
segments( longscafs_x[1:(nscafs_x-1)], barpos_x[1:(nscafs_x-1)], longscafs_x[2:nscafs_x], barpos_x[0:(nscafs_x-1)], lwd=2)
segments(longscafs_x, 0, longscafs_x, longscafs_y[nscafs_y], lwd=0.1, col="#777777")
tickpoints = pretty(c(0,250))
axis(2, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_y = rep(c( xmax*-0.01, xmax*-0.02),round(nscafs_y)/2)
segments( barpos_y[1:(nscafs_y-1)], longscafs_y[1:(nscafs_y-1)], barpos_y[0:(nscafs_y-1)], longscafs_y[2:nscafs_y], lwd=2)
segments( 0, longscafs_y, longscafs_x[nscafs_x], longscafs_y, lwd=0.1, col="#777777")
textpos_y = rep(c( xmax*-0.02, xmax*-0.01 ),round(24)/2)
textmidbar = as.numeric(scafdata1[1:24,6]) - as.numeric(scafdata1[1:24,4])/2
text(textpos_y, textmidbar, 1:24, cex=0.2)
rect(longscafs2[4],longscafs1[22],longscafs2[5],longscafs1[23], border="#ff2211aa", lwd=3)
par( mar=c(1.5,1.5,1,1.5) )

allg1chr_genes = pointsdata[pointsdata[,3]=="scaffold_0022",]
allg2chr_genes = pointsdata[pointsdata[,5]=="scaffold_5",]
selectedpoints = allg1chr_genes[allg1chr_genes[,5]=="scaffold_5",]

plot(0,0,type="n", xlim=c(-0.2,1.2), ylim=c(-1,8.5), xlab="", ylab="", frame.plot=FALSE, axes=FALSE)
rect(0.1, 0, 0.2, (longscafs1[23]-longscafs1[22])/1000000, col="#c7e9c0")
segments( rep(0.1,dim(allg1chr_genes)[1]), (allg1chr_genes[,6]-longscafs1[22])/1000000, rep(0.2,dim(allg1chr_genes)[1]), (allg1chr_genes[,6]-longscafs1[22])/1000000, lwd=2 )
text(0.2,-0.5, "E. muelleri\nscaffold_0022", cex=1.1)
rect(0.8, 0, 0.9, (longscafs2[5]-longscafs2[4])/1000000, col="#5bbfdf")
segments( rep(0.8,dim(allg2chr_genes)[1]), (allg2chr_genes[,7]-longscafs2[4])/1000000, rep(0.9,dim(allg2chr_genes)[1]), (allg2chr_genes[,7]-longscafs2[4])/1000000, lwd=2 )
text(0.8,-0.5, "T. adhaerens\nscaffold_5", cex=1.1)
segments( rep(0.2,dim(selectedpoints)[1]), (selectedpoints[,6]-longscafs1[22])/1000000, rep(0.8,dim(selectedpoints)[1]), (selectedpoints[,7]-longscafs2[4])/1000000, col="#0e992f88", lwd=1.5)
axis(2,at=seq(0,7,1),cex.axis=1.2,line=-3)
axis(4,at=seq(0,8,1),cex.axis=1.2,line=-3)
mtext("Length (Mb)",side=2, cex=1.1)
dev.off()





outputfile = "~/genomes/ephydatia_muelleri/synteny/ephydatia_Bf_synteny_dot_plots_w_chr22.pdf"
pdf(file=outputfile, width=8, height=5)
par( mar=c(3.5,4.5,1,0.5) )
par( mfrow=c(1,2) )
all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Brafl2-AUG_scaffold2D.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
longestscaf1 = max(scafdata1[,6])
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.01)
longscafs1 = c(0, scafdata1[,6][is_longscafs1] )
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
longestscaf2 = max(scafdata2[,6])
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.0009)
longscafs2 = c(0, scafdata2[,6][is_longscafs2] )
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
longscafpoints = pointsdata[,6] < 270000000
genome_x = pointsdata[,7][longscafpoints]
genome_y = pointsdata[,6][longscafpoints]
xmax = tail( pretty(longscafs2), n=1)
ymax = tail( pretty(longscafs1), n=1)
longscafs_x = longscafs2
longscafs_y = longscafs1
nscafs_x = length(longscafs2)
nscafs_y = length(longscafs1)
xmax_mb = round(xmax / 1000000)
ymax_mb = round(ymax / 1000000)
pointsize = log10(as.numeric(pointsdata[,8])) / 6
plot(genome_x, genome_y, pch=16, xlim=c(0,200000000), ylim=c(0,270000000), col="#18935188", cex=pointsize, main="Branchiostoma floridae", font.main=3, xlab="", ylab="Total size (Mb)", axes=FALSE, cex.lab=1.4)
tickpoints = pretty(c(0,200))
axis(1, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_x = rep(c( ymax*-0.01, ymax*-0.02),round(nscafs_x)/2)
segments( longscafs_x[1:(nscafs_x-1)], barpos_x[1:(nscafs_x-1)], longscafs_x[2:nscafs_x], barpos_x[0:(nscafs_x-1)], lwd=2)
segments(longscafs_x, 0, longscafs_x, longscafs_y[nscafs_y], lwd=0.1, col="#777777")
tickpoints = pretty(c(0,250))
axis(2, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_y = rep(c( xmax*-0.01, xmax*-0.02),round(nscafs_y)/2)
segments( barpos_y[1:(nscafs_y-1)], longscafs_y[1:(nscafs_y-1)], barpos_y[0:(nscafs_y-1)], longscafs_y[2:nscafs_y], lwd=2)
segments( 0, longscafs_y, longscafs_x[nscafs_x], longscafs_y, lwd=0.1, col="#777777")
textpos_y = rep(c( xmax*-0.02, xmax*-0.01 ),round(24)/2)
textmidbar = as.numeric(scafdata1[1:24,6]) - as.numeric(scafdata1[1:24,4])/2
text(textpos_y, textmidbar, 1:24, cex=0.2)
rect(longscafs2[2],longscafs1[22],longscafs2[3],longscafs1[23], border="#ff2211aa", lwd=3)
#rect(longscafs2[17],longscafs1[22],longscafs2[18],longscafs1[23], border="#ff221166", lwd=3)
par( mar=c(1.5,1.5,1,1.5) )

allg1chr_genes = pointsdata[pointsdata[,3]=="scaffold_0022",]
allg2chr_genes = pointsdata[pointsdata[,5]=="Bf_V2_21",]
selectedpoints = allg1chr_genes[allg1chr_genes[,5]=="Bf_V2_21",]

plot(0,0,type="n", xlim=c(-0.2,1.2), ylim=c(-1,11), xlab="", ylab="", frame.plot=FALSE, axes=FALSE)
rect(0.1, 0, 0.2, (longscafs1[23]-longscafs1[22])/1000000, col="#c7e9c0")
segments( rep(0.1,dim(allg1chr_genes)[1]), (allg1chr_genes[,6]-longscafs1[22])/1000000, rep(0.2,dim(allg1chr_genes)[1]), (allg1chr_genes[,6]-longscafs1[22])/1000000, lwd=2, col="#00000088" )
text(0.2,-0.7, "E. muelleri\nscaffold_0022", cex=1.1)
rect(0.8, 0, 0.9, (longscafs2[3]-longscafs2[2])/1000000, col="#c7e9c0")
segments( rep(0.8,dim(allg2chr_genes)[1]), (allg2chr_genes[,7]-longscafs2[2])/1000000, rep(0.9,dim(allg2chr_genes)[1]), (allg2chr_genes[,7]-longscafs2[2])/1000000, lwd=2, col="#00000088" )
text(0.8,-0.7, "B. floridae\nBf_V2_21", cex=1.1)
segments( rep(0.2,dim(selectedpoints)[1]), (selectedpoints[,6]-longscafs1[22])/1000000, rep(0.8,dim(selectedpoints)[1]), (selectedpoints[,7]-longscafs2[2])/1000000, col="#0e992f88", lwd=1.5)
axis(2,at=seq(0,7,1),cex.axis=1.2,line=-3)
axis(4,at=seq(0,10,1),cex.axis=1.2,line=-3)
mtext("Length (Mb)",side=2, cex=1.3)

dev.off()


############# try with both scaffolds from Brafl



outputfile = "~/genomes/ephydatia_muelleri/synteny/ephydatia_Bf_synteny_dot_plots_w_chr22.pdf"
pdf(file=outputfile, width=8, height=5)
par( mar=c(3.5,4.5,1,0.5) )
par( mfrow=c(1,2) )
all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Brafl2-AUG_scaffold2D.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
longestscaf1 = max(scafdata1[,6])
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.01)
longscafs1 = c(0, scafdata1[,6][is_longscafs1] )
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
longestscaf2 = max(scafdata2[,6])
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.0009)
longscafs2 = c(0, scafdata2[,6][is_longscafs2] )
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
longscafpoints = pointsdata[,6] < 270000000
genome_x = pointsdata[,7][longscafpoints]
genome_y = pointsdata[,6][longscafpoints]
xmax = tail( pretty(longscafs2), n=1)
ymax = tail( pretty(longscafs1), n=1)
longscafs_x = longscafs2
longscafs_y = longscafs1
nscafs_x = length(longscafs2)
nscafs_y = length(longscafs1)
xmax_mb = round(xmax / 1000000)
ymax_mb = round(ymax / 1000000)
pointsize = log10(as.numeric(pointsdata[,8])) / 6
plot(genome_x, genome_y, pch=16, xlim=c(0,200000000), ylim=c(0,270000000), col="#18935188", cex=pointsize, main="Branchiostoma floridae", font.main=3, xlab="", ylab="Total size (Mb)", axes=FALSE, cex.lab=1.4)
tickpoints = pretty(c(0,200))
axis(1, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_x = rep(c( ymax*-0.01, ymax*-0.02),round(nscafs_x)/2)
segments( longscafs_x[1:(nscafs_x-1)], barpos_x[1:(nscafs_x-1)], longscafs_x[2:nscafs_x], barpos_x[0:(nscafs_x-1)], lwd=2)
segments(longscafs_x, 0, longscafs_x, longscafs_y[nscafs_y], lwd=0.1, col="#777777")
tickpoints = pretty(c(0,250))
axis(2, at=tickpoints*1000000, labels=tickpoints, cex.axis=1.3)
barpos_y = rep(c( xmax*-0.01, xmax*-0.02),round(nscafs_y)/2)
segments( barpos_y[1:(nscafs_y-1)], longscafs_y[1:(nscafs_y-1)], barpos_y[0:(nscafs_y-1)], longscafs_y[2:nscafs_y], lwd=2)
segments( 0, longscafs_y, longscafs_x[nscafs_x], longscafs_y, lwd=0.1, col="#777777")
textpos_y = rep(c( xmax*-0.02, xmax*-0.01 ),round(24)/2)
textmidbar = as.numeric(scafdata1[1:24,6]) - as.numeric(scafdata1[1:24,4])/2
text(textpos_y, textmidbar, 1:24, cex=0.2)
rect(longscafs2[2],longscafs1[22],longscafs2[3],longscafs1[23], border="#ff2211aa", lwd=3)
rect(longscafs2[17],longscafs1[22],longscafs2[18],longscafs1[23], border="#ff2211aa", lwd=3)
par( mar=c(1.5,1.5,1,1.5) )

allg1chr_genes = pointsdata[pointsdata[,3]=="scaffold_0022",]
allg2chr_genes = pointsdata[pointsdata[,5]=="Bf_V2_21",]
selectedpoints = allg1chr_genes[allg1chr_genes[,5]=="Bf_V2_21",]

plot(0,0,type="n", xlim=c(-0.8,1.2), ylim=c(-1,11), xlab="", ylab="", frame.plot=FALSE, axes=FALSE)
rect(0.1, 0, 0.2, (longscafs1[23]-longscafs1[22])/1000000, col="#c7e9c0")
segments( rep(0.1,dim(allg1chr_genes)[1]), (allg1chr_genes[,6]-longscafs1[22])/1000000, rep(0.2,dim(allg1chr_genes)[1]), (allg1chr_genes[,6]-longscafs1[22])/1000000, lwd=2, col="#00000088" )
text(0.15, 8.7, "E. muelleri\nscaffold_0022", cex=1.1)
rect(-0.6, 0, -0.5, (longscafs2[3]-longscafs2[2])/1000000, col="#bb8ce6")
segments( rep(-0.6,dim(allg2chr_genes)[1]), (allg2chr_genes[,7]-longscafs2[2])/1000000, rep(-0.5,dim(allg2chr_genes)[1]), (allg2chr_genes[,7]-longscafs2[2])/1000000, lwd=2, col="#00000088" )
text(-0.5,-0.7, "B. floridae\nBf_V2_21", cex=1.1)
segments( rep(0.1,dim(selectedpoints)[1]), (selectedpoints[,6]-longscafs1[22])/1000000, rep(-0.5,dim(selectedpoints)[1]), (selectedpoints[,7]-longscafs2[2])/1000000, col="#0e992f88", lwd=1.5)
axis(2,at=seq(0,10,1),cex.axis=1.2,line=-1.5)
axis(4,at=seq(0,10,1),cex.axis=1.2,line=-2)
mtext("Length (Mb)",side=2, cex=1.3, line=1)

allg2chr_genes = pointsdata[pointsdata[,5]=="Bf_V2_150",]
selectedpoints = allg1chr_genes[allg1chr_genes[,5]=="Bf_V2_150",]
rect(0.8, 0, 0.9, (longscafs2[18]-longscafs2[17])/1000000, col="#bb8ce6")
segments( rep(0.8,dim(allg2chr_genes)[1]), (allg2chr_genes[,7]-longscafs2[17])/1000000, rep(0.9,dim(allg2chr_genes)[1]), (allg2chr_genes[,7]-longscafs2[17])/1000000, lwd=2, col="#00000088" )
text(0.8,-0.7, "B. floridae\nBf_V2_150", cex=1.1)
segments( rep(0.2,dim(selectedpoints)[1]), (selectedpoints[,6]-longscafs1[22])/1000000, rep(0.8,dim(selectedpoints)[1]), (selectedpoints[,7]-longscafs2[17])/1000000, col="#0e992f88", lwd=1.5)

dev.off()


#